@@ -452,11 +452,13 @@ void GUI::loadState(KSharedConfigPtr cfg)
     show_menu_bar_action->setChecked(!menubar_hidden);
 
     bool minimize_to_system_tray = Settings::alwaysMinimizeToSystemTray();
+
+    const auto w = window()->windowHandle();
     if (Settings::showSystemTrayIcon() && minimize_to_system_tray) {
         Out(SYS_GEN | LOG_DEBUG) << "Starting minimized" << endl;
-        hide();
+        w->hide();
     } else {
-        show();
+        w->show();
     }
 
     setCurrentActivity(central->currentActivity());
@@ -477,12 +479,14 @@ void GUI::saveState(KSharedConfigPtr cfg)
 
 bool GUI::queryClose()
 {
-    if (Settings::showSystemTrayIcon() && !qApp->isSavingSession()) {
-        hide();
+    if (window()->windowHandle()->isVisible()) {
         saveState(KSharedConfig::openConfig());
+    }
+
+    if (Settings::showSystemTrayIcon() && !qApp->isSavingSession()) {
+        window()->windowHandle()->hide();
         return false;
     } else {
-        saveState(KSharedConfig::openConfig());
         timer.stop();
         QTimer::singleShot(500, qApp, &QCoreApplication::quit);
         return true;
@@ -491,7 +495,6 @@ bool GUI::queryClose()
 
 void GUI::quit()
 {
-    saveState(KSharedConfig::openConfig());
     qApp->quit();
 }
 
@@ -502,7 +505,11 @@ void GUI::updateActions()
 
 void GUI::showOrHide()
 {
-    setVisible(!isVisible());
+    const auto w = window()->windowHandle();
+    if (w->isVisible())
+        w->hide();
+    else
+        w->show();
 }
 
 void GUI::configureNotifications()
