@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2007 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "iwfilelistmodel.h"
 
@@ -87,14 +72,16 @@ QVariant IWFileListModel::headerData(int section, Qt::Orientation orientation, i
 static QString PriorityString(const bt::TorrentFileInterface *file)
 {
     switch (file->getPriority()) {
+    case FIRST_PREVIEW_PRIORITY:
     case FIRST_PRIORITY:
         return i18nc("Download first", "First");
+    case LAST_PREVIEW_PRIORITY:
     case LAST_PRIORITY:
         return i18nc("Download last", "Last");
     case ONLY_SEED_PRIORITY:
     case EXCLUDED:
-    case PREVIEW_PRIORITY:
         return QString();
+    case NORMAL_PREVIEW_PRIORITY:
     default:
         return i18nc("Download Normal (not as first or last)", "Normal");
     }
@@ -111,15 +98,17 @@ QVariant IWFileListModel::data(const QModelIndex &index, int role) const
     if (role == Qt::ForegroundRole && index.column() == 2 && tc->getStats().multi_file_torrent) {
         const bt::TorrentFileInterface *file = &tc->getTorrentFile(index.row());
         switch (file->getPriority()) {
+        case FIRST_PREVIEW_PRIORITY:
         case FIRST_PRIORITY:
             return InfoWidgetPluginSettings::firstColor();
+        case LAST_PREVIEW_PRIORITY:
         case LAST_PRIORITY:
             return InfoWidgetPluginSettings::lastColor();
+        case NORMAL_PREVIEW_PRIORITY:
         case NORMAL_PRIORITY:
             return QVariant();
         case ONLY_SEED_PRIORITY:
         case EXCLUDED:
-        case PREVIEW_PRIORITY:
         default:
             return QVariant();
         }
@@ -234,7 +223,7 @@ bool IWFileListModel::setData(const QModelIndex &index, const QVariant &value, i
 
     if (prio != old) {
         file.setPriority(prio);
-        dataChanged(createIndex(index.row(), 0), createIndex(index.row(), 4));
+        Q_EMIT dataChanged(createIndex(index.row(), 0), createIndex(index.row(), 4));
     }
 
     return true;
@@ -280,7 +269,9 @@ void IWFileListModel::update()
         }
 
         if (changed)
-            dataChanged(createIndex(0, 0), createIndex(0, 4));
+            Q_EMIT dataChanged(createIndex(0, 0), createIndex(0, 4));
     }
 }
 }
+
+#include "moc_iwfilelistmodel.cpp"
